# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/judge.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.annotations import service_pb2 as eolymp_dot_annotations_dot_service__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.judge import activity_pb2 as eolymp_dot_judge_dot_activity__pb2
from eolymp.judge import announcement_pb2 as eolymp_dot_judge_dot_announcement__pb2
from eolymp.judge import contest_pb2 as eolymp_dot_judge_dot_contest__pb2
from eolymp.judge import entitlement_pb2 as eolymp_dot_judge_dot_entitlement__pb2
from eolymp.judge import participant_pb2 as eolymp_dot_judge_dot_participant__pb2
from eolymp.judge import problem_pb2 as eolymp_dot_judge_dot_problem__pb2
from eolymp.judge import reply_pb2 as eolymp_dot_judge_dot_reply__pb2
from eolymp.judge import result_pb2 as eolymp_dot_judge_dot_result__pb2
from eolymp.judge import score_pb2 as eolymp_dot_judge_dot_score__pb2
from eolymp.judge import scoreboard_pb2 as eolymp_dot_judge_dot_scoreboard__pb2
from eolymp.judge import submission_pb2 as eolymp_dot_judge_dot_submission__pb2
from eolymp.judge import ticket_pb2 as eolymp_dot_judge_dot_ticket__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x65olymp/judge/judge.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a eolymp/annotations/service.proto\x1a!eolymp/wellknown/expression.proto\x1a eolymp/wellknown/direction.proto\x1a\x1b\x65olymp/judge/activity.proto\x1a\x1f\x65olymp/judge/announcement.proto\x1a\x1a\x65olymp/judge/contest.proto\x1a\x1e\x65olymp/judge/entitlement.proto\x1a\x1e\x65olymp/judge/participant.proto\x1a\x1a\x65olymp/judge/problem.proto\x1a\x18\x65olymp/judge/reply.proto\x1a\x19\x65olymp/judge/result.proto\x1a\x18\x65olymp/judge/score.proto\x1a\x1d\x65olymp/judge/scoreboard.proto\x1a\x1d\x65olymp/judge/submission.proto\x1a\x19\x65olymp/judge/ticket.proto\"<\n\x12\x43reateContestInput\x12&\n\x07\x63ontest\x18\x01 \x01(\x0b\x32\x15.eolymp.judge.Contest\")\n\x13\x43reateContestOutput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"(\n\x12\x44\x65leteContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x15\n\x13\x44\x65leteContestOutput\"P\n\x12UpdateContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12&\n\x07\x63ontest\x18\x02 \x01(\x0b\x32\x15.eolymp.judge.Contest\"\x15\n\x13UpdateContestOutput\"*\n\x14\x44\x65scribeContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"?\n\x15\x44\x65scribeContestOutput\x12&\n\x07\x63ontest\x18\x01 \x01(\x0b\x32\x15.eolymp.judge.Contest\"!\n\x12LookupContestInput\x12\x0b\n\x03key\x18\x01 \x01(\t\"s\n\x13LookupContestOutput\x12&\n\x07\x63ontest\x18\x01 \x01(\x0b\x32\x15.eolymp.judge.Contest\x12\x34\n\nappearance\x18\x02 \x01(\x0b\x32 .eolymp.judge.Contest.Appearance\"\x8e\x04\n\x11ListContestsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x37\n\x07\x66ilters\x18( \x01(\x0b\x32&.eolymp.judge.ListContestsInput.Filter\x1a\xa1\x03\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12-\n\x03own\x18\x02 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x30\n\x04name\x18\x03 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x38\n\tstarts_at\x18\x04 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12\x36\n\x07\x65nds_at\x18\x05 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12\x30\n\x06public\x18\x06 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x34\n\nvisibility\x18\x07 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x06\x66ormat\x18\x08 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"I\n\x12ListContestsOutput\x12$\n\x05items\x18\x01 \x03(\x0b\x32\x15.eolymp.judge.Contest\x12\r\n\x05total\x18\x02 \x01(\x05\"&\n\x10OpenContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x13\n\x11OpenContestOutput\"\'\n\x11\x43loseContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x14\n\x12\x43loseContestOutput\"&\n\x10JoinContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x13\n\x11JoinContestOutput\"\'\n\x11StartContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x14\n\x12StartContestOutput\"\x7f\n\x12ImportProblemInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x11\n\timport_id\x18\x02 \x01(\t\x12\r\n\x05index\x18\n \x01(\r\x12\x14\n\x0csubmit_limit\x18\x0b \x01(\r\x12\x1d\n\x15score_by_best_testset\x18\x0c \x01(\x08\")\n\x13ImportProblemOutput\x12\x12\n\nproblem_id\x18\x02 \x01(\t\"&\n\x10SyncProblemInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"\x13\n\x11SyncProblemOutput\"l\n\x12UpdateProblemInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\r\n\x05index\x18\n \x01(\r\x12\x14\n\x0csubmit_limit\x18\x0b \x01(\r\x12\x1d\n\x15score_by_best_testset\x18\x0c \x01(\x08\"\x15\n\x13UpdateProblemOutput\"(\n\x12\x44\x65leteProblemInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"\x15\n\x13\x44\x65leteProblemOutput\"(\n\x12RetestProblemInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"\x15\n\x13RetestProblemOutput\"E\n\x11ListProblemsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"I\n\x12ListProblemsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12$\n\x05items\x18\x02 \x03(\x0b\x32\x15.eolymp.judge.Problem\"*\n\x14\x44\x65scribeProblemInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"?\n\x15\x44\x65scribeProblemOutput\x12&\n\x07problem\x18\x01 \x01(\x0b\x32\x15.eolymp.judge.Problem\")\n\x13ListStatementsInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"U\n\x14ListStatementsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12.\n\x05items\x18\x02 \x03(\x0b\x32\x1f.eolymp.judge.Problem.Statement\"*\n\x14ListAttachmentsInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"W\n\x15ListAttachmentsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12/\n\x05items\x18\x02 \x03(\x0b\x32 .eolymp.judge.Problem.Attachment\"\'\n\x11ListExamplesInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"N\n\x12ListExamplesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12)\n\x05items\x18\x02 \x03(\x0b\x32\x1a.eolymp.judge.Problem.Test\"J\n\x13\x41\x64\x64ParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\".\n\x14\x41\x64\x64ParticipantOutput\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\"0\n\x16\x45nableParticipantInput\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\"\x19\n\x17\x45nableParticipantOutput\"1\n\x17\x44isableParticipantInput\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\"\x1a\n\x18\x44isableParticipantOutput\"\xb9\x01\n\x16UpdateParticipantInput\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\x12\x39\n\x05patch\x18\x02 \x01(\x0e\x32*.eolymp.judge.UpdateParticipantInput.Patch\x12\x0c\n\x04name\x18\n \x01(\t\x12\x12\n\nbonus_time\x18\x0c \x01(\r\"*\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x08\n\x04NAME\x10\x01\x12\x0e\n\nBONUS_TIME\x10\x03\"\x19\n\x17UpdateParticipantOutput\"0\n\x16RemoveParticipantInput\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\"\x19\n\x17RemoveParticipantOutput\")\n\x13VerifyPasscodeInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"7\n\x14VerifyPasscodeOutput\x12\x10\n\x08required\x18\x01 \x01(\x08\x12\r\n\x05valid\x18\x02 \x01(\x08\":\n\x12\x45nterPasscodeInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x10\n\x08passcode\x18\x02 \x01(\t\"\x15\n\x13\x45nterPasscodeOutput\",\n\x12ResetPasscodeInput\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\"\'\n\x13ResetPasscodeOutput\x12\x10\n\x08passcode\x18\x01 \x01(\t\"-\n\x13RemovePasscodeInput\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\"\x16\n\x14RemovePasscodeOutput\"\xe8\x05\n\x15ListParticipantsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.judge.ListParticipantsInput.Filter\x12:\n\x04sort\x18\x32 \x01(\x0e\x32,.eolymp.judge.ListParticipantsInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x1a\xa8\x03\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmember_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x08 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x30\n\x06status\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x05score\x18\x04 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\x12\x32\n\x07penalty\x18\x05 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\x12\x39\n\nstarted_at\x18\x06 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12:\n\x0b\x63omplete_at\x18\x07 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\"M\n\x08Sortable\x12\x08\n\x04RANK\x10\x00\x12\t\n\x05SCORE\x10\x01\x12\x0b\n\x07PENALTY\x10\x02\x12\x0e\n\nSTARTED_AT\x10\x03\x12\x0f\n\x0b\x43OMPLETE_AT\x10\x04\"Q\n\x16ListParticipantsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.judge.Participant\"0\n\x1aIntrospectParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"M\n\x1bIntrospectParticipantOutput\x12.\n\x0bparticipant\x18\x01 \x01(\x0b\x32\x19.eolymp.judge.Participant\"2\n\x18\x44\x65scribeParticipantInput\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\"K\n\x19\x44\x65scribeParticipantOutput\x12.\n\x0bparticipant\x18\x01 \x01(\x0b\x32\x19.eolymp.judge.Participant\"I\n\x15\x43reateSubmissionInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0c\n\x04lang\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\"/\n\x16\x43reateSubmissionOutput\x12\x15\n\rsubmission_id\x18\x01 \x01(\t\"\xe4\x04\n\x14ListSubmissionsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.judge.ListSubmissionsInput.Filter\x1a\xdd\x03\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x36\n\x0eparticipant_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x32\n\nproblem_id\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06status\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12.\n\x04lang\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x05score\x18\x06 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\x12\x35\n\npercentage\x18\x07 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\x12;\n\x0csubmitted_at\x18\x08 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12\x33\n\tsignature\x18\t \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"O\n\x15ListSubmissionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.judge.Submission\"0\n\x17\x44\x65scribeSubmissionInput\x12\x15\n\rsubmission_id\x18\x01 \x01(\t\"H\n\x18\x44\x65scribeSubmissionOutput\x12,\n\nsubmission\x18\x01 \x01(\x0b\x32\x18.eolymp.judge.Submission\".\n\x15RetestSubmissionInput\x12\x15\n\rsubmission_id\x18\x01 \x01(\t\"\x18\n\x16RetestSubmissionOutput\"I\n\x11\x43reateTicketInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"\'\n\x12\x43reateTicketOutput\x12\x11\n\tticket_id\x18\x01 \x01(\t\"%\n\x10\x43loseTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\"\x13\n\x11\x43loseTicketOutput\"$\n\x0fOpenTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\"\x12\n\x10OpenTicketOutput\"$\n\x0fReadTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\"\x12\n\x10ReadTicketOutput\"&\n\x11\x44\x65leteTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\"\x14\n\x12\x44\x65leteTicketOutput\"(\n\x13\x44\x65scribeTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\"<\n\x14\x44\x65scribeTicketOutput\x12$\n\x06ticket\x18\x01 \x01(\x0b\x32\x14.eolymp.judge.Ticket\"\x96\x05\n\x10ListTicketsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x36\n\x07\x66ilters\x18( \x01(\x0b\x32%.eolymp.judge.ListTicketsInput.Filter\x12\x35\n\x04sort\x18\x32 \x01(\x0e\x32\'.eolymp.judge.ListTicketsInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x1a\x80\x03\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x32\n\ncontest_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x36\n\x0eparticipant_id\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12@\n\x16is_read_by_participant\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12:\n\x10is_read_by_owner\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x31\n\x07is_open\x18\x06 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12-\n\x03own\x18\x07 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\"F\n\x08Sortable\x12\x0e\n\nCREATED_AT\x10\x00\x12\x11\n\rREAD_BY_OWNER\x10\x01\x12\x17\n\x13READ_BY_PARTICIPANT\x10\x02\"G\n\x11ListTicketsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12#\n\x05items\x18\x02 \x03(\x0b\x32\x14.eolymp.judge.Ticket\"E\n\x10ReplyTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\n \x01(\t\x12\r\n\x05\x63lose\x18\x15 \x01(\x08\"%\n\x11ReplyTicketOutput\x12\x10\n\x08reply_id\x18\x01 \x01(\t\"C\n\x10ListRepliesInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"F\n\x11ListRepliesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\"\n\x05items\x18\x02 \x03(\x0b\x32\x13.eolymp.judge.Reply\"$\n\x10\x44\x65leteReplyInput\x12\x10\n\x08reply_id\x18\x01 \x01(\t\"\x13\n\x11\x44\x65leteReplyOutput\"5\n\x10UpdateReplyInput\x12\x10\n\x08reply_id\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x13\n\x11UpdateReplyOutput\"<\n\x15\x43onfigureRuntimeInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0f\n\x07runtime\x18\x02 \x03(\t\"\x18\n\x16\x43onfigureRuntimeOutput\"*\n\x14\x44\x65scribeRuntimeInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"(\n\x15\x44\x65scribeRuntimeOutput\x12\x0f\n\x07runtime\x18\x01 \x03(\t\"[\n\x15\x43onfigureScoringInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12.\n\x07scoring\x18\x02 \x01(\x0b\x32\x1d.eolymp.judge.Contest.Scoring\"\x18\n\x16\x43onfigureScoringOutput\"*\n\x14\x44\x65scribeScoringInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"G\n\x15\x44\x65scribeScoringOutput\x12.\n\x07scoring\x18\x01 \x01(\x0b\x32\x1d.eolymp.judge.Contest.Scoring\"_\n\x17\x43reateAnnouncementInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x30\n\x0c\x61nnouncement\x18\x02 \x01(\x0b\x32\x1a.eolymp.judge.Announcement\"&\n\x18\x43reateAnnouncementOutput\x12\n\n\x02id\x18\x01 \x01(\t\"d\n\x17UpdateAnnouncementInput\x12\x17\n\x0f\x61nnouncement_id\x18\x01 \x01(\t\x12\x30\n\x0c\x61nnouncement\x18\x02 \x01(\x0b\x32\x1a.eolymp.judge.Announcement\"\x1a\n\x18UpdateAnnouncementOutput\"2\n\x17\x44\x65leteAnnouncementInput\x12\x17\n\x0f\x61nnouncement_id\x18\x01 \x01(\t\"\x1a\n\x18\x44\x65leteAnnouncementOutput\"0\n\x15ReadAnnouncementInput\x12\x17\n\x0f\x61nnouncement_id\x18\x01 \x01(\t\"\x18\n\x16ReadAnnouncementOutput\"4\n\x19\x44\x65scribeAnnouncementInput\x12\x17\n\x0f\x61nnouncement_id\x18\x01 \x01(\t\"N\n\x1a\x44\x65scribeAnnouncementOutput\x12\x30\n\x0c\x61nnouncement\x18\x01 \x01(\x0b\x32\x1a.eolymp.judge.Announcement\":\n\x1f\x44\x65scribeAnnouncementStatusInput\x12\x17\n\x0f\x61nnouncement_id\x18\x01 \x01(\t\"3\n DescribeAnnouncementStatusOutput\x12\x0f\n\x07is_read\x18\x01 \x01(\x08\"\xf1\x01\n\x16ListAnnouncementsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12<\n\x07\x66ilters\x18( \x01(\x0b\x32+.eolymp.judge.ListAnnouncementsInput.Filter\x1ag\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\x07is_read\x18\x02 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\"S\n\x17ListAnnouncementsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12)\n\x05items\x18\x02 \x03(\x0b\x32\x1a.eolymp.judge.Announcement\"C\n\x19\x44\x65scribeCodeTemplateInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x12\n\nruntime_id\x18\x02 \x01(\t\".\n\x1a\x44\x65scribeCodeTemplateOutput\x12\x10\n\x08template\x18\x01 \x01(\t\"Y\n\x15\x43reateScoreboardInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12,\n\nscoreboard\x18\x02 \x01(\x0b\x32\x18.eolymp.judge.Scoreboard\"/\n\x16\x43reateScoreboardOutput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"\\\n\x15UpdateScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12,\n\nscoreboard\x18\x02 \x01(\x0b\x32\x18.eolymp.judge.Scoreboard\"\x18\n\x16UpdateScoreboardOutput\"\'\n\x11RebuildScoreInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\")\n\x12RebuildScoreOutput\x12\x13\n\x0b\x61\x63tivity_id\x18\x01 \x01(\t\".\n\x15\x44\x65leteScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"\x18\n\x16\x44\x65leteScoreboardOutput\"0\n\x17\x44\x65scribeScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"H\n\x18\x44\x65scribeScoreboardOutput\x12,\n\nscoreboard\x18\x01 \x01(\x0b\x32\x18.eolymp.judge.Scoreboard\"4\n\x1e\x44\x65scribeDefaultScoreboardInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"O\n\x1f\x44\x65scribeDefaultScoreboardOutput\x12,\n\nscoreboard\x18\x01 \x01(\x0b\x32\x18.eolymp.judge.Scoreboard\"\xa1\x02\n\x14ListScoreboardsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.judge.ListScoreboardsInput.Filter\x1a\x9a\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\x07visible\x18\x02 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x31\n\x07\x64\x65\x66\x61ult\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\"O\n\x15ListScoreboardsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.judge.Scoreboard\"6\n\x1d\x44\x65scribeScoreboardHeaderInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"\x9b\x01\n\x1e\x44\x65scribeScoreboardHeaderOutput\x12\x46\n\x08problems\x18\x03 \x03(\x0b\x32\x34.eolymp.judge.DescribeScoreboardHeaderOutput.Problem\x1a\x31\n\x07Problem\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x12\n\nshort_name\x18\x02 \x01(\t\"6\n\x1d\x44\x65scribeScoreboardFooterInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"\xb9\x01\n\x1e\x44\x65scribeScoreboardFooterOutput\x12\x46\n\x08problems\x18\x03 \x03(\x0b\x32\x34.eolymp.judge.DescribeScoreboardFooterOutput.Problem\x1aO\n\x07Problem\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x16\n\x0etotal_attempts\x18\x02 \x01(\r\x12\x18\n\x10success_attempts\x18\x03 \x01(\r\"K\n\x1a\x44\x65scribeScoreboardRowInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\"H\n\x1b\x44\x65scribeScoreboardRowOutput\x12)\n\x03row\x18\x01 \x01(\x0b\x32\x1c.eolymp.judge.Scoreboard.Row\"*\n\x14IntrospectScoreInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\";\n\x15IntrospectScoreOutput\x12\"\n\x05score\x18\x01 \x01(\x0b\x32\x13.eolymp.judge.Score\"q\n\x12\x44\x65scribeScoreInput\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\x12.\n\x04mode\x18\x02 \x01(\x0e\x32 .eolymp.judge.Score.FetchingMode\x12\x13\n\x0btime_offset\x18\x03 \x01(\x05\"9\n\x13\x44\x65scribeScoreOutput\x12\"\n\x05score\x18\x01 \x01(\x0b\x32\x13.eolymp.judge.Score\"O\n\x10ImportScoreInput\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\x12#\n\x06scores\x18\x02 \x03(\x0b\x32\x13.eolymp.judge.Score\"\x13\n\x11ImportScoreOutput\"\x88\x01\n\x0fListResultInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12.\n\x04mode\x18\x02 \x01(\x0e\x32 .eolymp.judge.Score.FetchingMode\x12\x13\n\x0btime_offset\x18\x03 \x01(\x05\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"F\n\x10ListResultOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12#\n\x05items\x18\x02 \x03(\x0b\x32\x14.eolymp.judge.Result\"O\n!DescribeDefaultScoreboardRowInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\"O\n\"DescribeDefaultScoreboardRowOutput\x12)\n\x03row\x18\x01 \x01(\x0b\x32\x1c.eolymp.judge.Scoreboard.Row\"\xc4\x04\n\x17ListScoreboardRowsInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12=\n\x07\x66ilters\x18( \x01(\x0b\x32,.eolymp.judge.ListScoreboardRowsInput.Filter\x1a\xb4\x03\n\x06\x46ilter\x12\x36\n\x0eparticipant_id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmember_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x08 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x30\n\x06status\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x05score\x18\x04 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\x12\x32\n\x07penalty\x18\x05 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\x12\x39\n\nstarted_at\x18\x06 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12:\n\x0b\x63omplete_at\x18\x07 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\"V\n\x18ListScoreboardRowsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12+\n\x05items\x18\x02 \x03(\x0b\x32\x1c.eolymp.judge.Scoreboard.Row\"\x91\x01\n\x1eListDefaultScoreboardRowsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12=\n\x07\x66ilters\x18( \x01(\x0b\x32,.eolymp.judge.ListScoreboardRowsInput.Filter\"]\n\x1fListDefaultScoreboardRowsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12+\n\x05items\x18\x02 \x03(\x0b\x32\x1c.eolymp.judge.Scoreboard.Row\"\x80\x01\n\x15ListEntitlementsInput\x12\x14\n\ncontest_id\x18\x01 \x01(\tH\x00\x12\x17\n\rsubmission_id\x18\x02 \x01(\tH\x00\x12\x13\n\tticket_id\x18\x03 \x01(\tH\x00\x12\x18\n\x0eparticipant_id\x18\x04 \x01(\tH\x00\x42\t\n\x07\x63ontext\"I\n\x16ListEntitlementsOutput\x12/\n\x0c\x65ntitlements\x18\x01 \x03(\x0e\x32\x19.eolymp.judge.Entitlement\"G\n\x13ListActivitiesInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"L\n\x14ListActivitiesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.judge.Activity\"d\n\x18\x43onfigureAppearanceInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x34\n\nappearance\x18\x02 \x01(\x0b\x32 .eolymp.judge.Contest.Appearance\"\x1b\n\x19\x43onfigureAppearanceOutput\"-\n\x17\x44\x65scribeAppearanceInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"P\n\x18\x44\x65scribeAppearanceOutput\x12\x34\n\nappearance\x18\x01 \x01(\x0b\x32 .eolymp.judge.Contest.Appearance2\x86s\n\x05Judge\x12\xa0\x01\n\rCreateContest\x12 .eolymp.judge.CreateContestInput\x1a!.eolymp.judge.CreateContestOutput\"J\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7\xa3=\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1a\"\x0f/judge/contests:\x07\x63ontest\x12\xa4\x01\n\rDeleteContest\x12 .eolymp.judge.DeleteContestInput\x1a!.eolymp.judge.DeleteContestOutput\"N\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e*\x1c/judge/contests/{contest_id}\x12\xad\x01\n\rUpdateContest\x12 .eolymp.judge.UpdateContestInput\x1a!.eolymp.judge.UpdateContestOutput\"W\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\'\x1a\x1c/judge/contests/{contest_id}:\x07\x63ontest\x12\x8c\x01\n\rLookupContest\x12 .eolymp.judge.LookupContestInput\x1a!.eolymp.judge.LookupContestOutput\"6\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02 \x12\x1b/judge/contest-lookup/{key}b\x01*\x12\x98\x01\n\x0f\x44\x65scribeContest\x12\".eolymp.judge.DescribeContestInput\x1a#.eolymp.judge.DescribeContestOutput\"<\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\'\x12\x1c/judge/contests/{contest_id}b\x07\x63ontest\x12y\n\x0cListContests\x12\x1f.eolymp.judge.ListContestsInput\x1a .eolymp.judge.ListContestsOutput\"&\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x11\x12\x0f/judge/contests\x12\xa3\x01\n\x0bOpenContest\x12\x1e.eolymp.judge.OpenContestInput\x1a\x1f.eolymp.judge.OpenContestOutput\"S\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02#\"!/judge/contests/{contest_id}/open\x12\xa7\x01\n\x0c\x43loseContest\x12\x1f.eolymp.judge.CloseContestInput\x1a .eolymp.judge.CloseContestOutput\"T\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02$\"\"/judge/contests/{contest_id}/close\x12\xb5\x01\n\x10\x43onfigureRuntime\x12#.eolymp.judge.ConfigureRuntimeInput\x1a$.eolymp.judge.ConfigureRuntimeOutput\"V\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02&\"$/judge/contests/{contest_id}/runtime\x12\xb1\x01\n\x0f\x44\x65scribeRuntime\x12\".eolymp.judge.DescribeRuntimeInput\x1a#.eolymp.judge.DescribeRuntimeOutput\"U\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02&\x12$/judge/contests/{contest_id}/runtime\x12\xc1\x01\n\x13\x43onfigureAppearance\x12&.eolymp.judge.ConfigureAppearanceInput\x1a\'.eolymp.judge.ConfigureAppearanceOutput\"Y\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02)\"\'/judge/contests/{contest_id}/appearance\x12\xbd\x01\n\x12\x44\x65scribeAppearance\x12%.eolymp.judge.DescribeAppearanceInput\x1a&.eolymp.judge.DescribeAppearanceOutput\"X\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02)\x12\'/judge/contests/{contest_id}/appearance\x12\xb5\x01\n\x10\x43onfigureScoring\x12#.eolymp.judge.ConfigureScoringInput\x1a$.eolymp.judge.ConfigureScoringOutput\"V\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02&\"$/judge/contests/{contest_id}/scoring\x12\xb1\x01\n\x0f\x44\x65scribeScoring\x12\".eolymp.judge.DescribeScoringInput\x1a#.eolymp.judge.DescribeScoringOutput\"U\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02&\x12$/judge/contests/{contest_id}/scoring\x12\xb3\x01\n\rImportProblem\x12 .eolymp.judge.ImportProblemInput\x1a!.eolymp.judge.ImportProblemOutput\"]\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02-\"+/judge/contests/{contest_id}/import/problem\x12\xa3\x01\n\x0bSyncProblem\x12\x1e.eolymp.judge.SyncProblemInput\x1a\x1f.eolymp.judge.SyncProblemOutput\"S\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02#\"!/judge/problems/{problem_id}/sync\x12\xa4\x01\n\rUpdateProblem\x12 .eolymp.judge.UpdateProblemInput\x1a!.eolymp.judge.UpdateProblemOutput\"N\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e\"\x1c/judge/problems/{problem_id}\x12\xa9\x01\n\x0cListProblems\x12\x1f.eolymp.judge.ListProblemsInput\x1a .eolymp.judge.ListProblemsOutput\"V\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00@@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\'\x12%/judge/contests/{contest_id}/problems\x12\xa9\x01\n\x0f\x44\x65scribeProblem\x12\".eolymp.judge.DescribeProblemInput\x1a#.eolymp.judge.DescribeProblemOutput\"M\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x1e\x12\x1c/judge/problems/{problem_id}\x12\xd2\x01\n\x14\x44\x65scribeCodeTemplate\x12\'.eolymp.judge.DescribeCodeTemplateInput\x1a(.eolymp.judge.DescribeCodeTemplateOutput\"g\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x38\x12\x33/judge/problems/{problem_id}/templates/{runtime_id}b\x01*\x12\xb1\x01\n\x0eListStatements\x12!.eolymp.judge.ListStatementsInput\x1a\".eolymp.judge.ListStatementsOutput\"X\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02)\x12\'/judge/problems/{problem_id}/statements\x12\xb5\x01\n\x0fListAttachments\x12\".eolymp.judge.ListAttachmentsInput\x1a#.eolymp.judge.ListAttachmentsOutput\"Y\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02*\x12(/judge/problems/{problem_id}/attachments\x12\xaa\x01\n\x0cListExamples\x12\x1f.eolymp.judge.ListExamplesInput\x1a .eolymp.judge.ListExamplesOutput\"W\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02(\x12&/judge/problems/{problem_id}/examples/\x12\xa4\x01\n\rDeleteProblem\x12 .eolymp.judge.DeleteProblemInput\x1a!.eolymp.judge.DeleteProblemOutput\"N\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e*\x1c/judge/problems/{problem_id}\x12\xae\x01\n\rRetestProblem\x12 .eolymp.judge.RetestProblemInput\x1a!.eolymp.judge.RetestProblemOutput\"X\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02(\x12#/judge/problems/{problem_id}/retestb\x01*\x12\xb7\x01\n\x0e\x41\x64\x64Participant\x12!.eolymp.judge.AddParticipantInput\x1a\".eolymp.judge.AddParticipantOutput\"^\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02.\")/judge/contests/{contest_id}/participants:\x01*\x12\xbf\x01\n\x11\x45nableParticipant\x12$.eolymp.judge.EnableParticipantInput\x1a%.eolymp.judge.EnableParticipantOutput\"]\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02-\"+/judge/participants/{participant_id}/enable\x12\xc3\x01\n\x12\x44isableParticipant\x12%.eolymp.judge.DisableParticipantInput\x1a&.eolymp.judge.DisableParticipantOutput\"^\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02.\",/judge/participants/{participant_id}/disable\x12\xbb\x01\n\x11UpdateParticipant\x12$.eolymp.judge.UpdateParticipantInput\x1a%.eolymp.judge.UpdateParticipantOutput\"Y\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02)\x1a$/judge/participants/{participant_id}:\x01*\x12\xb8\x01\n\x11RemoveParticipant\x12$.eolymp.judge.RemoveParticipantInput\x1a%.eolymp.judge.RemoveParticipantOutput\"V\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02&*$/judge/participants/{participant_id}\x12\xb9\x01\n\x10ListParticipants\x12#.eolymp.judge.ListParticipantsInput\x1a$.eolymp.judge.ListParticipantsOutput\"Z\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02+\x12)/judge/contests/{contest_id}/participants\x12\xcb\x01\n\x13\x44\x65scribeParticipant\x12&.eolymp.judge.DescribeParticipantInput\x1a\'.eolymp.judge.DescribeParticipantOutput\"c\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02\x33\x12$/judge/participants/{participant_id}b\x0bparticipant\x12\xb9\x01\n\x15IntrospectParticipant\x12(.eolymp.judge.IntrospectParticipantInput\x1a).eolymp.judge.IntrospectParticipantOutput\"K\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x36\x12\'/judge/contests/{contest_id}/introspectb\x0bparticipant\x12\x88\x01\n\x0bJoinContest\x12\x1e.eolymp.judge.JoinContestInput\x1a\x1f.eolymp.judge.JoinContestOutput\"8\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x03\x82\xd3\xe4\x93\x02#\"!/judge/contests/{contest_id}/join\x12\xad\x01\n\x0cStartContest\x12\x1f.eolymp.judge.StartContestInput\x1a .eolymp.judge.StartContestOutput\"Z\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x03\x82\xd3\xe4\x93\x02$\"\"/judge/contests/{contest_id}/start\x12\xaf\x01\n\x0eVerifyPasscode\x12!.eolymp.judge.VerifyPasscodeInput\x1a\".eolymp.judge.VerifyPasscodeOutput\"V\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\'\x12%/judge/contests/{contest_id}/passcode\x12\xb3\x01\n\rEnterPasscode\x12 .eolymp.judge.EnterPasscodeInput\x1a!.eolymp.judge.EnterPasscodeOutput\"]\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\'\"%/judge/contests/{contest_id}/passcode\x12\xb5\x01\n\rResetPasscode\x12 .eolymp.judge.ResetPasscodeInput\x1a!.eolymp.judge.ResetPasscodeOutput\"_\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02/\"-/judge/participants/{participant_id}/passcode\x12\xb8\x01\n\x0eRemovePasscode\x12!.eolymp.judge.RemovePasscodeInput\x1a\".eolymp.judge.RemovePasscodeOutput\"_\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02/*-/judge/participants/{participant_id}/passcode\x12\xc2\x01\n\x10\x43reateSubmission\x12#.eolymp.judge.CreateSubmissionInput\x1a$.eolymp.judge.CreateSubmissionOutput\"c\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\n\x82\xd3\xe4\x93\x02-\"(/judge/problems/{problem_id}/submissions:\x01*\x12\x97\x02\n\x0fListSubmissions\x12\".eolymp.judge.ListSubmissionsInput\x1a#.eolymp.judge.ListSubmissionsOutput\"\xba\x01\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x8a\x01\x12(/judge/contests/{contest_id}/submissionsZ*\x12(/judge/problems/{problem_id}/submissionsZ2\x12\x30/judge/participants/{participant_id}/submissions\x12\xc4\x01\n\x12\x44\x65scribeSubmission\x12%.eolymp.judge.DescribeSubmissionInput\x1a&.eolymp.judge.DescribeSubmissionOutput\"_\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x30\x12\"/judge/submissions/{submission_id}b\nsubmission\x12\xbd\x01\n\x10RetestSubmission\x12#.eolymp.judge.RetestSubmissionInput\x1a$.eolymp.judge.RetestSubmissionOutput\"^\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02.\x12)/judge/submissions/{submission_id}/retestb\x01*\x12\xb2\x01\n\x0c\x43reateTicket\x12\x1f.eolymp.judge.CreateTicketInput\x1a .eolymp.judge.CreateTicketOutput\"_\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02)\"$/judge/contests/{contest_id}/ticketsb\x01*\x12\xa5\x01\n\x0b\x43loseTicket\x12\x1e.eolymp.judge.CloseTicketInput\x1a\x1f.eolymp.judge.CloseTicketOutput\"U\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02%\" /judge/tickets/{ticket_id}/closeb\x01*\x12\xa1\x01\n\nOpenTicket\x12\x1d.eolymp.judge.OpenTicketInput\x1a\x1e.eolymp.judge.OpenTicketOutput\"T\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02$\"\x1f/judge/tickets/{ticket_id}/openb\x01*\x12\xa0\x01\n\nReadTicket\x12\x1d.eolymp.judge.ReadTicketInput\x1a\x1e.eolymp.judge.ReadTicketOutput\"S\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02$\"\x1f/judge/tickets/{ticket_id}/readb\x01*\x12\xa2\x01\n\x0c\x44\x65leteTicket\x12\x1f.eolymp.judge.DeleteTicketInput\x1a .eolymp.judge.DeleteTicketOutput\"O\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x1f*\x1a/judge/tickets/{ticket_id}b\x01*\x12\xac\x01\n\x0e\x44\x65scribeTicket\x12!.eolymp.judge.DescribeTicketInput\x1a\".eolymp.judge.DescribeTicketOutput\"S\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02$\x12\x1a/judge/tickets/{ticket_id}b\x06ticket\x12\x92\x01\n\x0bListTickets\x12\x1e.eolymp.judge.ListTicketsInput\x1a\x1f.eolymp.judge.ListTicketsOutput\"B\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x13\x12\x0e/judge/ticketsb\x01*\x12\xad\x01\n\x0bReplyTicket\x12\x1e.eolymp.judge.ReplyTicketInput\x1a\x1f.eolymp.judge.ReplyTicketOutput\"]\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\'\"\"/judge/tickets/{ticket_id}/repliesb\x01*\x12\xa6\x01\n\x0bListReplies\x12\x1e.eolymp.judge.ListRepliesInput\x1a\x1f.eolymp.judge.ListRepliesOutput\"V\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\'\x12\"/judge/tickets/{ticket_id}/repliesb\x01*\x12\x9e\x01\n\x0b\x44\x65leteReply\x12\x1e.eolymp.judge.DeleteReplyInput\x1a\x1f.eolymp.judge.DeleteReplyOutput\"N\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e*\x19/judge/replies/{reply_id}b\x01*\x12\x9e\x01\n\x0bUpdateReply\x12\x1e.eolymp.judge.UpdateReplyInput\x1a\x1f.eolymp.judge.UpdateReplyOutput\"N\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e\"\x19/judge/replies/{reply_id}b\x01*\x12\xc4\x01\n\x12\x43reateAnnouncement\x12%.eolymp.judge.CreateAnnouncementInput\x1a&.eolymp.judge.CreateAnnouncementOutput\"_\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02/\"*/judge/contests/{contest_id}/announcementsb\x01*\x12\xbd\x01\n\x12UpdateAnnouncement\x12%.eolymp.judge.UpdateAnnouncementInput\x1a&.eolymp.judge.UpdateAnnouncementOutput\"X\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02(\"&/judge/announcements/{announcement_id}\x12\xbd\x01\n\x12\x44\x65leteAnnouncement\x12%.eolymp.judge.DeleteAnnouncementInput\x1a&.eolymp.judge.DeleteAnnouncementOutput\"X\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02(*&/judge/announcements/{announcement_id}\x12\xbe\x01\n\x10ReadAnnouncement\x12#.eolymp.judge.ReadAnnouncementInput\x1a$.eolymp.judge.ReadAnnouncementOutput\"_\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x30\"+/judge/announcements/{announcement_id}/readb\x01*\x12\xd0\x01\n\x14\x44\x65scribeAnnouncement\x12\'.eolymp.judge.DescribeAnnouncementInput\x1a(.eolymp.judge.DescribeAnnouncementOutput\"e\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x36\x12&/judge/announcements/{announcement_id}b\x0c\x61nnouncement\x12\xde\x01\n\x1a\x44\x65scribeAnnouncementStatus\x12-.eolymp.judge.DescribeAnnouncementStatusInput\x1a..eolymp.judge.DescribeAnnouncementStatusOutput\"a\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x32\x12-/judge/announcements/{announcement_id}/statusb\x01*\x12\xc0\x01\n\x11ListAnnouncements\x12$.eolymp.judge.ListAnnouncementsInput\x1a%.eolymp.judge.ListAnnouncementsOutput\"^\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02/\x12*/judge/contests/{contest_id}/announcementsb\x01*\x12\xa7\x01\n\x0fIntrospectScore\x12\".eolymp.judge.IntrospectScoreInput\x1a#.eolymp.judge.IntrospectScoreOutput\"K\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x36\x12-/judge/contests/{contest_id}/introspect/scoreb\x05score\x12\xb9\x01\n\rDescribeScore\x12 .eolymp.judge.DescribeScoreInput\x1a!.eolymp.judge.DescribeScoreOutput\"c\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02\x33\x12*/judge/participants/{participant_id}/scoreb\x05score\x12\xb0\x01\n\x0bImportScore\x12\x1e.eolymp.judge.ImportScoreInput\x1a\x1f.eolymp.judge.ImportScoreOutput\"`\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02\x30\"+/judge/participants/{participant_id}/scoresb\x01*\x12\xa6\x01\n\nListResult\x12\x1d.eolymp.judge.ListResultInput\x1a\x1e.eolymp.judge.ListResultOutput\"Y\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02)\x12$/judge/contests/{contest_id}/resultsb\x01*\x12\xbc\x01\n\x10\x43reateScoreboard\x12#.eolymp.judge.CreateScoreboardInput\x1a$.eolymp.judge.CreateScoreboardOutput\"]\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02-\"(/judge/contests/{contest_id}/scoreboardsb\x01*\x12\xb3\x01\n\x10UpdateScoreboard\x12#.eolymp.judge.UpdateScoreboardInput\x1a$.eolymp.judge.UpdateScoreboardOutput\"T\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02$\"\"/judge/scoreboards/{scoreboard_id}\x12\xa9\x01\n\x0cRebuildScore\x12\x1f.eolymp.judge.RebuildScoreInput\x1a .eolymp.judge.RebuildScoreOutput\"V\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02&\"$/judge/contests/{contest_id}/rebuild\x12\xb3\x01\n\x10\x44\x65leteScoreboard\x12#.eolymp.judge.DeleteScoreboardInput\x1a$.eolymp.judge.DeleteScoreboardOutput\"T\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02$*\"/judge/scoreboards/{scoreboard_id}\x12\xc4\x01\n\x12\x44\x65scribeScoreboard\x12%.eolymp.judge.DescribeScoreboardInput\x1a&.eolymp.judge.DescribeScoreboardOutput\"_\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x30\x12\"/judge/scoreboards/{scoreboard_id}b\nscoreboard\x12\xde\x01\n\x19\x44\x65scribeDefaultScoreboard\x12,.eolymp.judge.DescribeDefaultScoreboardInput\x1a-.eolymp.judge.DescribeDefaultScoreboardOutput\"d\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x35\x12\'/judge/contests/{contest_id}/scoreboardb\nscoreboard\x12\xb8\x01\n\x0fListScoreboards\x12\".eolymp.judge.ListScoreboardsInput\x1a#.eolymp.judge.ListScoreboardsOutput\"\\\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02-\x12(/judge/contests/{contest_id}/scoreboardsb\x01*\x12\xd4\x01\n\x18\x44\x65scribeScoreboardHeader\x12+.eolymp.judge.DescribeScoreboardHeaderInput\x1a,.eolymp.judge.DescribeScoreboardHeaderOutput\"]\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02.\x12)/judge/scoreboards/{scoreboard_id}/headerb\x01*\x12\xd4\x01\n\x18\x44\x65scribeScoreboardFooter\x12+.eolymp.judge.DescribeScoreboardFooterInput\x1a,.eolymp.judge.DescribeScoreboardFooterOutput\"]\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02.\x12)/judge/scoreboards/{scoreboard_id}/footerb\x01*\x12\xdd\x01\n\x15\x44\x65scribeScoreboardRow\x12(.eolymp.judge.DescribeScoreboardRowInput\x1a).eolymp.judge.DescribeScoreboardRowOutput\"o\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02?\x12\x38/judge/scoreboards/{scoreboard_id}/rows/{participant_id}b\x03row\x12\xf7\x01\n\x1c\x44\x65scribeDefaultScoreboardRow\x12/.eolymp.judge.DescribeDefaultScoreboardRowInput\x1a\x30.eolymp.judge.DescribeDefaultScoreboardRowOutput\"t\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02\x44\x12=/judge/contests/{contest_id}/scoreboard/rows/{participant_id}b\x03row\x12\xc0\x01\n\x12ListScoreboardRows\x12%.eolymp.judge.ListScoreboardRowsInput\x1a&.eolymp.judge.ListScoreboardRowsOutput\"[\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02,\x12\'/judge/scoreboards/{scoreboard_id}/rowsb\x01*\x12\xda\x01\n\x19ListDefaultScoreboardRows\x12,.eolymp.judge.ListDefaultScoreboardRowsInput\x1a-.eolymp.judge.ListDefaultScoreboardRowsOutput\"`\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x31\x12,/judge/contests/{contest_id}/scoreboard/rowsb\x01*\x12\x89\x01\n\x10ListEntitlements\x12#.eolymp.judge.ListEntitlementsInput\x1a$.eolymp.judge.ListEntitlementsOutput\"*\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x15\x12\x13/judge/entitlements\x12\xb4\x01\n\x0eListActivities\x12!.eolymp.judge.ListActivitiesInput\x1a\".eolymp.judge.ListActivitiesOutput\"[\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02,\x12\'/judge/contests/{contest_id}/activitiesb\x01*\x1a\x06\xb2\xe3\n\x02\x08\x01\x42\x33Z1github.com/eolymp/contracts/go/eolymp/judge;judgeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.judge_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/contracts/go/eolymp/judge;judge'
  _JUDGE._options = None
  _JUDGE._serialized_options = b'\262\343\n\002\010\001'
  _JUDGE.methods_by_name['CreateContest']._options = None
  _JUDGE.methods_by_name['CreateContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\n\327\243=\370\342\n\005\202\323\344\223\002\032\"\017/judge/contests:\007contest'
  _JUDGE.methods_by_name['DeleteContest']._options = None
  _JUDGE.methods_by_name['DeleteContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\036*\034/judge/contests/{contest_id}'
  _JUDGE.methods_by_name['UpdateContest']._options = None
  _JUDGE.methods_by_name['UpdateContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\'\032\034/judge/contests/{contest_id}:\007contest'
  _JUDGE.methods_by_name['LookupContest']._options = None
  _JUDGE.methods_by_name['LookupContest']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\323\344\223\002 \022\033/judge/contest-lookup/{key}b\001*'
  _JUDGE.methods_by_name['DescribeContest']._options = None
  _JUDGE.methods_by_name['DescribeContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\'\022\034/judge/contests/{contest_id}b\007contest'
  _JUDGE.methods_by_name['ListContests']._options = None
  _JUDGE.methods_by_name['ListContests']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\021\022\017/judge/contests'
  _JUDGE.methods_by_name['OpenContest']._options = None
  _JUDGE.methods_by_name['OpenContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002#\"!/judge/contests/{contest_id}/open'
  _JUDGE.methods_by_name['CloseContest']._options = None
  _JUDGE.methods_by_name['CloseContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002$\"\"/judge/contests/{contest_id}/close'
  _JUDGE.methods_by_name['ConfigureRuntime']._options = None
  _JUDGE.methods_by_name['ConfigureRuntime']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002&\"$/judge/contests/{contest_id}/runtime'
  _JUDGE.methods_by_name['DescribeRuntime']._options = None
  _JUDGE.methods_by_name['DescribeRuntime']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002&\022$/judge/contests/{contest_id}/runtime'
  _JUDGE.methods_by_name['ConfigureAppearance']._options = None
  _JUDGE.methods_by_name['ConfigureAppearance']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002)\"\'/judge/contests/{contest_id}/appearance'
  _JUDGE.methods_by_name['DescribeAppearance']._options = None
  _JUDGE.methods_by_name['DescribeAppearance']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002)\022\'/judge/contests/{contest_id}/appearance'
  _JUDGE.methods_by_name['ConfigureScoring']._options = None
  _JUDGE.methods_by_name['ConfigureScoring']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002&\"$/judge/contests/{contest_id}/scoring'
  _JUDGE.methods_by_name['DescribeScoring']._options = None
  _JUDGE.methods_by_name['DescribeScoring']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002&\022$/judge/contests/{contest_id}/scoring'
  _JUDGE.methods_by_name['ImportProblem']._options = None
  _JUDGE.methods_by_name['ImportProblem']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002-\"+/judge/contests/{contest_id}/import/problem'
  _JUDGE.methods_by_name['SyncProblem']._options = None
  _JUDGE.methods_by_name['SyncProblem']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002#\"!/judge/problems/{problem_id}/sync'
  _JUDGE.methods_by_name['UpdateProblem']._options = None
  _JUDGE.methods_by_name['UpdateProblem']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\036\"\034/judge/problems/{problem_id}'
  _JUDGE.methods_by_name['ListProblems']._options = None
  _JUDGE.methods_by_name['ListProblems']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000@@\370\342\n\n\202\323\344\223\002\'\022%/judge/contests/{contest_id}/problems'
  _JUDGE.methods_by_name['DescribeProblem']._options = None
  _JUDGE.methods_by_name['DescribeProblem']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\036\022\034/judge/problems/{problem_id}'
  _JUDGE.methods_by_name['DescribeCodeTemplate']._options = None
  _JUDGE.methods_by_name['DescribeCodeTemplate']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\0028\0223/judge/problems/{problem_id}/templates/{runtime_id}b\001*'
  _JUDGE.methods_by_name['ListStatements']._options = None
  _JUDGE.methods_by_name['ListStatements']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002)\022\'/judge/problems/{problem_id}/statements'
  _JUDGE.methods_by_name['ListAttachments']._options = None
  _JUDGE.methods_by_name['ListAttachments']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002*\022(/judge/problems/{problem_id}/attachments'
  _JUDGE.methods_by_name['ListExamples']._options = None
  _JUDGE.methods_by_name['ListExamples']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002(\022&/judge/problems/{problem_id}/examples/'
  _JUDGE.methods_by_name['DeleteProblem']._options = None
  _JUDGE.methods_by_name['DeleteProblem']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\036*\034/judge/problems/{problem_id}'
  _JUDGE.methods_by_name['RetestProblem']._options = None
  _JUDGE.methods_by_name['RetestProblem']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002(\022#/judge/problems/{problem_id}/retestb\001*'
  _JUDGE.methods_by_name['AddParticipant']._options = None
  _JUDGE.methods_by_name['AddParticipant']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002.\")/judge/contests/{contest_id}/participants:\001*'
  _JUDGE.methods_by_name['EnableParticipant']._options = None
  _JUDGE.methods_by_name['EnableParticipant']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002-\"+/judge/participants/{participant_id}/enable'
  _JUDGE.methods_by_name['DisableParticipant']._options = None
  _JUDGE.methods_by_name['DisableParticipant']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002.\",/judge/participants/{participant_id}/disable'
  _JUDGE.methods_by_name['UpdateParticipant']._options = None
  _JUDGE.methods_by_name['UpdateParticipant']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002)\032$/judge/participants/{participant_id}:\001*'
  _JUDGE.methods_by_name['RemoveParticipant']._options = None
  _JUDGE.methods_by_name['RemoveParticipant']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002&*$/judge/participants/{participant_id}'
  _JUDGE.methods_by_name['ListParticipants']._options = None
  _JUDGE.methods_by_name['ListParticipants']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002+\022)/judge/contests/{contest_id}/participants'
  _JUDGE.methods_by_name['DescribeParticipant']._options = None
  _JUDGE.methods_by_name['DescribeParticipant']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\323\344\223\0023\022$/judge/participants/{participant_id}b\013participant'
  _JUDGE.methods_by_name['IntrospectParticipant']._options = None
  _JUDGE.methods_by_name['IntrospectParticipant']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\0026\022\'/judge/contests/{contest_id}/introspectb\013participant'
  _JUDGE.methods_by_name['JoinContest']._options = None
  _JUDGE.methods_by_name['JoinContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\003\202\323\344\223\002#\"!/judge/contests/{contest_id}/join'
  _JUDGE.methods_by_name['StartContest']._options = None
  _JUDGE.methods_by_name['StartContest']._serialized_options = b'\202\343\n\035\212\343\n\031judge:contest:participate\352\342\n\013\365\342\n\000\000\200?\370\342\n\003\202\323\344\223\002$\"\"/judge/contests/{contest_id}/start'
  _JUDGE.methods_by_name['VerifyPasscode']._options = None
  _JUDGE.methods_by_name['VerifyPasscode']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\'\022%/judge/contests/{contest_id}/passcode'
  _JUDGE.methods_by_name['EnterPasscode']._options = None
  _JUDGE.methods_by_name['EnterPasscode']._serialized_options = b'\202\343\n\035\212\343\n\031judge:contest:participate\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\'\"%/judge/contests/{contest_id}/passcode'
  _JUDGE.methods_by_name['ResetPasscode']._options = None
  _JUDGE.methods_by_name['ResetPasscode']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002/\"-/judge/participants/{participant_id}/passcode'
  _JUDGE.methods_by_name['RemovePasscode']._options = None
  _JUDGE.methods_by_name['RemovePasscode']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002/*-/judge/participants/{participant_id}/passcode'
  _JUDGE.methods_by_name['CreateSubmission']._options = None
  _JUDGE.methods_by_name['CreateSubmission']._serialized_options = b'\202\343\n\035\212\343\n\031judge:contest:participate\352\342\n\013\365\342\n\n\327#>\370\342\n\n\202\323\344\223\002-\"(/judge/problems/{problem_id}/submissions:\001*'
  _JUDGE.methods_by_name['ListSubmissions']._options = None
  _JUDGE.methods_by_name['ListSubmissions']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\212\001\022(/judge/contests/{contest_id}/submissionsZ*\022(/judge/problems/{problem_id}/submissionsZ2\0220/judge/participants/{participant_id}/submissions'
  _JUDGE.methods_by_name['DescribeSubmission']._options = None
  _JUDGE.methods_by_name['DescribeSubmission']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\0020\022\"/judge/submissions/{submission_id}b\nsubmission'
  _JUDGE.methods_by_name['RetestSubmission']._options = None
  _JUDGE.methods_by_name['RetestSubmission']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002.\022)/judge/submissions/{submission_id}/retestb\001*'
  _JUDGE.methods_by_name['CreateTicket']._options = None
  _JUDGE.methods_by_name['CreateTicket']._serialized_options = b'\202\343\n\035\212\343\n\031judge:contest:participate\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002)\"$/judge/contests/{contest_id}/ticketsb\001*'
  _JUDGE.methods_by_name['CloseTicket']._options = None
  _JUDGE.methods_by_name['CloseTicket']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002%\" /judge/tickets/{ticket_id}/closeb\001*'
  _JUDGE.methods_by_name['OpenTicket']._options = None
  _JUDGE.methods_by_name['OpenTicket']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002$\"\037/judge/tickets/{ticket_id}/openb\001*'
  _JUDGE.methods_by_name['ReadTicket']._options = None
  _JUDGE.methods_by_name['ReadTicket']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002$\"\037/judge/tickets/{ticket_id}/readb\001*'
  _JUDGE.methods_by_name['DeleteTicket']._options = None
  _JUDGE.methods_by_name['DeleteTicket']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\037*\032/judge/tickets/{ticket_id}b\001*'
  _JUDGE.methods_by_name['DescribeTicket']._options = None
  _JUDGE.methods_by_name['DescribeTicket']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002$\022\032/judge/tickets/{ticket_id}b\006ticket'
  _JUDGE.methods_by_name['ListTickets']._options = None
  _JUDGE.methods_by_name['ListTickets']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\023\022\016/judge/ticketsb\001*'
  _JUDGE.methods_by_name['ReplyTicket']._options = None
  _JUDGE.methods_by_name['ReplyTicket']._serialized_options = b'\202\343\n\035\212\343\n\031judge:contest:participate\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\'\"\"/judge/tickets/{ticket_id}/repliesb\001*'
  _JUDGE.methods_by_name['ListReplies']._options = None
  _JUDGE.methods_by_name['ListReplies']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\'\022\"/judge/tickets/{ticket_id}/repliesb\001*'
  _JUDGE.methods_by_name['DeleteReply']._options = None
  _JUDGE.methods_by_name['DeleteReply']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\036*\031/judge/replies/{reply_id}b\001*'
  _JUDGE.methods_by_name['UpdateReply']._options = None
  _JUDGE.methods_by_name['UpdateReply']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\036\"\031/judge/replies/{reply_id}b\001*'
  _JUDGE.methods_by_name['CreateAnnouncement']._options = None
  _JUDGE.methods_by_name['CreateAnnouncement']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002/\"*/judge/contests/{contest_id}/announcementsb\001*'
  _JUDGE.methods_by_name['UpdateAnnouncement']._options = None
  _JUDGE.methods_by_name['UpdateAnnouncement']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002(\"&/judge/announcements/{announcement_id}'
  _JUDGE.methods_by_name['DeleteAnnouncement']._options = None
  _JUDGE.methods_by_name['DeleteAnnouncement']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002(*&/judge/announcements/{announcement_id}'
  _JUDGE.methods_by_name['ReadAnnouncement']._options = None
  _JUDGE.methods_by_name['ReadAnnouncement']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\0020\"+/judge/announcements/{announcement_id}/readb\001*'
  _JUDGE.methods_by_name['DescribeAnnouncement']._options = None
  _JUDGE.methods_by_name['DescribeAnnouncement']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\0026\022&/judge/announcements/{announcement_id}b\014announcement'
  _JUDGE.methods_by_name['DescribeAnnouncementStatus']._options = None
  _JUDGE.methods_by_name['DescribeAnnouncementStatus']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\0022\022-/judge/announcements/{announcement_id}/statusb\001*'
  _JUDGE.methods_by_name['ListAnnouncements']._options = None
  _JUDGE.methods_by_name['ListAnnouncements']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002/\022*/judge/contests/{contest_id}/announcementsb\001*'
  _JUDGE.methods_by_name['IntrospectScore']._options = None
  _JUDGE.methods_by_name['IntrospectScore']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\0026\022-/judge/contests/{contest_id}/introspect/scoreb\005score'
  _JUDGE.methods_by_name['DescribeScore']._options = None
  _JUDGE.methods_by_name['DescribeScore']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\323\344\223\0023\022*/judge/participants/{participant_id}/scoreb\005score'
  _JUDGE.methods_by_name['ImportScore']._options = None
  _JUDGE.methods_by_name['ImportScore']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\323\344\223\0020\"+/judge/participants/{participant_id}/scoresb\001*'
  _JUDGE.methods_by_name['ListResult']._options = None
  _JUDGE.methods_by_name['ListResult']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\323\344\223\002)\022$/judge/contests/{contest_id}/resultsb\001*'
  _JUDGE.methods_by_name['CreateScoreboard']._options = None
  _JUDGE.methods_by_name['CreateScoreboard']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002-\"(/judge/contests/{contest_id}/scoreboardsb\001*'
  _JUDGE.methods_by_name['UpdateScoreboard']._options = None
  _JUDGE.methods_by_name['UpdateScoreboard']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002$\"\"/judge/scoreboards/{scoreboard_id}'
  _JUDGE.methods_by_name['RebuildScore']._options = None
  _JUDGE.methods_by_name['RebuildScore']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002&\"$/judge/contests/{contest_id}/rebuild'
  _JUDGE.methods_by_name['DeleteScoreboard']._options = None
  _JUDGE.methods_by_name['DeleteScoreboard']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002$*\"/judge/scoreboards/{scoreboard_id}'
  _JUDGE.methods_by_name['DescribeScoreboard']._options = None
  _JUDGE.methods_by_name['DescribeScoreboard']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\0020\022\"/judge/scoreboards/{scoreboard_id}b\nscoreboard'
  _JUDGE.methods_by_name['DescribeDefaultScoreboard']._options = None
  _JUDGE.methods_by_name['DescribeDefaultScoreboard']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\0025\022\'/judge/contests/{contest_id}/scoreboardb\nscoreboard'
  _JUDGE.methods_by_name['ListScoreboards']._options = None
  _JUDGE.methods_by_name['ListScoreboards']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002-\022(/judge/contests/{contest_id}/scoreboardsb\001*'
  _JUDGE.methods_by_name['DescribeScoreboardHeader']._options = None
  _JUDGE.methods_by_name['DescribeScoreboardHeader']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000 A\370\342\n\024\202\323\344\223\002.\022)/judge/scoreboards/{scoreboard_id}/headerb\001*'
  _JUDGE.methods_by_name['DescribeScoreboardFooter']._options = None
  _JUDGE.methods_by_name['DescribeScoreboardFooter']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000 A\370\342\n\024\202\323\344\223\002.\022)/judge/scoreboards/{scoreboard_id}/footerb\001*'
  _JUDGE.methods_by_name['DescribeScoreboardRow']._options = None
  _JUDGE.methods_by_name['DescribeScoreboardRow']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\323\344\223\002?\0228/judge/scoreboards/{scoreboard_id}/rows/{participant_id}b\003row'
  _JUDGE.methods_by_name['DescribeDefaultScoreboardRow']._options = None
  _JUDGE.methods_by_name['DescribeDefaultScoreboardRow']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\323\344\223\002D\022=/judge/contests/{contest_id}/scoreboard/rows/{participant_id}b\003row'
  _JUDGE.methods_by_name['ListScoreboardRows']._options = None
  _JUDGE.methods_by_name['ListScoreboardRows']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002,\022\'/judge/scoreboards/{scoreboard_id}/rowsb\001*'
  _JUDGE.methods_by_name['ListDefaultScoreboardRows']._options = None
  _JUDGE.methods_by_name['ListDefaultScoreboardRows']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\0021\022,/judge/contests/{contest_id}/scoreboard/rowsb\001*'
  _JUDGE.methods_by_name['ListEntitlements']._options = None
  _JUDGE.methods_by_name['ListEntitlements']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\025\022\023/judge/entitlements'
  _JUDGE.methods_by_name['ListActivities']._options = None
  _JUDGE.methods_by_name['ListActivities']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002,\022\'/judge/contests/{contest_id}/activitiesb\001*'
  _CREATECONTESTINPUT._serialized_start=594
  _CREATECONTESTINPUT._serialized_end=654
  _CREATECONTESTOUTPUT._serialized_start=656
  _CREATECONTESTOUTPUT._serialized_end=697
  _DELETECONTESTINPUT._serialized_start=699
  _DELETECONTESTINPUT._serialized_end=739
  _DELETECONTESTOUTPUT._serialized_start=741
  _DELETECONTESTOUTPUT._serialized_end=762
  _UPDATECONTESTINPUT._serialized_start=764
  _UPDATECONTESTINPUT._serialized_end=844
  _UPDATECONTESTOUTPUT._serialized_start=846
  _UPDATECONTESTOUTPUT._serialized_end=867
  _DESCRIBECONTESTINPUT._serialized_start=869
  _DESCRIBECONTESTINPUT._serialized_end=911
  _DESCRIBECONTESTOUTPUT._serialized_start=913
  _DESCRIBECONTESTOUTPUT._serialized_end=976
  _LOOKUPCONTESTINPUT._serialized_start=978
  _LOOKUPCONTESTINPUT._serialized_end=1011
  _LOOKUPCONTESTOUTPUT._serialized_start=1013
  _LOOKUPCONTESTOUTPUT._serialized_end=1128
  _LISTCONTESTSINPUT._serialized_start=1131
  _LISTCONTESTSINPUT._serialized_end=1657
  _LISTCONTESTSINPUT_FILTER._serialized_start=1240
  _LISTCONTESTSINPUT_FILTER._serialized_end=1657
  _LISTCONTESTSOUTPUT._serialized_start=1659
  _LISTCONTESTSOUTPUT._serialized_end=1732
  _OPENCONTESTINPUT._serialized_start=1734
  _OPENCONTESTINPUT._serialized_end=1772
  _OPENCONTESTOUTPUT._serialized_start=1774
  _OPENCONTESTOUTPUT._serialized_end=1793
  _CLOSECONTESTINPUT._serialized_start=1795
  _CLOSECONTESTINPUT._serialized_end=1834
  _CLOSECONTESTOUTPUT._serialized_start=1836
  _CLOSECONTESTOUTPUT._serialized_end=1856
  _JOINCONTESTINPUT._serialized_start=1858
  _JOINCONTESTINPUT._serialized_end=1896
  _JOINCONTESTOUTPUT._serialized_start=1898
  _JOINCONTESTOUTPUT._serialized_end=1917
  _STARTCONTESTINPUT._serialized_start=1919
  _STARTCONTESTINPUT._serialized_end=1958
  _STARTCONTESTOUTPUT._serialized_start=1960
  _STARTCONTESTOUTPUT._serialized_end=1980
  _IMPORTPROBLEMINPUT._serialized_start=1982
  _IMPORTPROBLEMINPUT._serialized_end=2109
  _IMPORTPROBLEMOUTPUT._serialized_start=2111
  _IMPORTPROBLEMOUTPUT._serialized_end=2152
  _SYNCPROBLEMINPUT._serialized_start=2154
  _SYNCPROBLEMINPUT._serialized_end=2192
  _SYNCPROBLEMOUTPUT._serialized_start=2194
  _SYNCPROBLEMOUTPUT._serialized_end=2213
  _UPDATEPROBLEMINPUT._serialized_start=2215
  _UPDATEPROBLEMINPUT._serialized_end=2323
  _UPDATEPROBLEMOUTPUT._serialized_start=2325
  _UPDATEPROBLEMOUTPUT._serialized_end=2346
  _DELETEPROBLEMINPUT._serialized_start=2348
  _DELETEPROBLEMINPUT._serialized_end=2388
  _DELETEPROBLEMOUTPUT._serialized_start=2390
  _DELETEPROBLEMOUTPUT._serialized_end=2411
  _RETESTPROBLEMINPUT._serialized_start=2413
  _RETESTPROBLEMINPUT._serialized_end=2453
  _RETESTPROBLEMOUTPUT._serialized_start=2455
  _RETESTPROBLEMOUTPUT._serialized_end=2476
  _LISTPROBLEMSINPUT._serialized_start=2478
  _LISTPROBLEMSINPUT._serialized_end=2547
  _LISTPROBLEMSOUTPUT._serialized_start=2549
  _LISTPROBLEMSOUTPUT._serialized_end=2622
  _DESCRIBEPROBLEMINPUT._serialized_start=2624
  _DESCRIBEPROBLEMINPUT._serialized_end=2666
  _DESCRIBEPROBLEMOUTPUT._serialized_start=2668
  _DESCRIBEPROBLEMOUTPUT._serialized_end=2731
  _LISTSTATEMENTSINPUT._serialized_start=2733
  _LISTSTATEMENTSINPUT._serialized_end=2774
  _LISTSTATEMENTSOUTPUT._serialized_start=2776
  _LISTSTATEMENTSOUTPUT._serialized_end=2861
  _LISTATTACHMENTSINPUT._serialized_start=2863
  _LISTATTACHMENTSINPUT._serialized_end=2905
  _LISTATTACHMENTSOUTPUT._serialized_start=2907
  _LISTATTACHMENTSOUTPUT._serialized_end=2994
  _LISTEXAMPLESINPUT._serialized_start=2996
  _LISTEXAMPLESINPUT._serialized_end=3035
  _LISTEXAMPLESOUTPUT._serialized_start=3037
  _LISTEXAMPLESOUTPUT._serialized_end=3115
  _ADDPARTICIPANTINPUT._serialized_start=3117
  _ADDPARTICIPANTINPUT._serialized_end=3191
  _ADDPARTICIPANTOUTPUT._serialized_start=3193
  _ADDPARTICIPANTOUTPUT._serialized_end=3239
  _ENABLEPARTICIPANTINPUT._serialized_start=3241
  _ENABLEPARTICIPANTINPUT._serialized_end=3289
  _ENABLEPARTICIPANTOUTPUT._serialized_start=3291
  _ENABLEPARTICIPANTOUTPUT._serialized_end=3316
  _DISABLEPARTICIPANTINPUT._serialized_start=3318
  _DISABLEPARTICIPANTINPUT._serialized_end=3367
  _DISABLEPARTICIPANTOUTPUT._serialized_start=3369
  _DISABLEPARTICIPANTOUTPUT._serialized_end=3395
  _UPDATEPARTICIPANTINPUT._serialized_start=3398
  _UPDATEPARTICIPANTINPUT._serialized_end=3583
  _UPDATEPARTICIPANTINPUT_PATCH._serialized_start=3541
  _UPDATEPARTICIPANTINPUT_PATCH._serialized_end=3583
  _UPDATEPARTICIPANTOUTPUT._serialized_start=3585
  _UPDATEPARTICIPANTOUTPUT._serialized_end=3610
  _REMOVEPARTICIPANTINPUT._serialized_start=3612
  _REMOVEPARTICIPANTINPUT._serialized_end=3660
  _REMOVEPARTICIPANTOUTPUT._serialized_start=3662
  _REMOVEPARTICIPANTOUTPUT._serialized_end=3687
  _VERIFYPASSCODEINPUT._serialized_start=3689
  _VERIFYPASSCODEINPUT._serialized_end=3730
  _VERIFYPASSCODEOUTPUT._serialized_start=3732
  _VERIFYPASSCODEOUTPUT._serialized_end=3787
  _ENTERPASSCODEINPUT._serialized_start=3789
  _ENTERPASSCODEINPUT._serialized_end=3847
  _ENTERPASSCODEOUTPUT._serialized_start=3849
  _ENTERPASSCODEOUTPUT._serialized_end=3870
  _RESETPASSCODEINPUT._serialized_start=3872
  _RESETPASSCODEINPUT._serialized_end=3916
  _RESETPASSCODEOUTPUT._serialized_start=3918
  _RESETPASSCODEOUTPUT._serialized_end=3957
  _REMOVEPASSCODEINPUT._serialized_start=3959
  _REMOVEPASSCODEINPUT._serialized_end=4004
  _REMOVEPASSCODEOUTPUT._serialized_start=4006
  _REMOVEPASSCODEOUTPUT._serialized_end=4028
  _LISTPARTICIPANTSINPUT._serialized_start=4031
  _LISTPARTICIPANTSINPUT._serialized_end=4775
  _LISTPARTICIPANTSINPUT_FILTER._serialized_start=4272
  _LISTPARTICIPANTSINPUT_FILTER._serialized_end=4696
  _LISTPARTICIPANTSINPUT_SORTABLE._serialized_start=4698
  _LISTPARTICIPANTSINPUT_SORTABLE._serialized_end=4775
  _LISTPARTICIPANTSOUTPUT._serialized_start=4777
  _LISTPARTICIPANTSOUTPUT._serialized_end=4858
  _INTROSPECTPARTICIPANTINPUT._serialized_start=4860
  _INTROSPECTPARTICIPANTINPUT._serialized_end=4908
  _INTROSPECTPARTICIPANTOUTPUT._serialized_start=4910
  _INTROSPECTPARTICIPANTOUTPUT._serialized_end=4987
  _DESCRIBEPARTICIPANTINPUT._serialized_start=4989
  _DESCRIBEPARTICIPANTINPUT._serialized_end=5039
  _DESCRIBEPARTICIPANTOUTPUT._serialized_start=5041
  _DESCRIBEPARTICIPANTOUTPUT._serialized_end=5116
  _CREATESUBMISSIONINPUT._serialized_start=5118
  _CREATESUBMISSIONINPUT._serialized_end=5191
  _CREATESUBMISSIONOUTPUT._serialized_start=5193
  _CREATESUBMISSIONOUTPUT._serialized_end=5240
  _LISTSUBMISSIONSINPUT._serialized_start=5243
  _LISTSUBMISSIONSINPUT._serialized_end=5855
  _LISTSUBMISSIONSINPUT_FILTER._serialized_start=5378
  _LISTSUBMISSIONSINPUT_FILTER._serialized_end=5855
  _LISTSUBMISSIONSOUTPUT._serialized_start=5857
  _LISTSUBMISSIONSOUTPUT._serialized_end=5936
  _DESCRIBESUBMISSIONINPUT._serialized_start=5938
  _DESCRIBESUBMISSIONINPUT._serialized_end=5986
  _DESCRIBESUBMISSIONOUTPUT._serialized_start=5988
  _DESCRIBESUBMISSIONOUTPUT._serialized_end=6060
  _RETESTSUBMISSIONINPUT._serialized_start=6062
  _RETESTSUBMISSIONINPUT._serialized_end=6108
  _RETESTSUBMISSIONOUTPUT._serialized_start=6110
  _RETESTSUBMISSIONOUTPUT._serialized_end=6134
  _CREATETICKETINPUT._serialized_start=6136
  _CREATETICKETINPUT._serialized_end=6209
  _CREATETICKETOUTPUT._serialized_start=6211
  _CREATETICKETOUTPUT._serialized_end=6250
  _CLOSETICKETINPUT._serialized_start=6252
  _CLOSETICKETINPUT._serialized_end=6289
  _CLOSETICKETOUTPUT._serialized_start=6291
  _CLOSETICKETOUTPUT._serialized_end=6310
  _OPENTICKETINPUT._serialized_start=6312
  _OPENTICKETINPUT._serialized_end=6348
  _OPENTICKETOUTPUT._serialized_start=6350
  _OPENTICKETOUTPUT._serialized_end=6368
  _READTICKETINPUT._serialized_start=6370
  _READTICKETINPUT._serialized_end=6406
  _READTICKETOUTPUT._serialized_start=6408
  _READTICKETOUTPUT._serialized_end=6426
  _DELETETICKETINPUT._serialized_start=6428
  _DELETETICKETINPUT._serialized_end=6466
  _DELETETICKETOUTPUT._serialized_start=6468
  _DELETETICKETOUTPUT._serialized_end=6488
  _DESCRIBETICKETINPUT._serialized_start=6490
  _DESCRIBETICKETINPUT._serialized_end=6530
  _DESCRIBETICKETOUTPUT._serialized_start=6532
  _DESCRIBETICKETOUTPUT._serialized_end=6592
  _LISTTICKETSINPUT._serialized_start=6595
  _LISTTICKETSINPUT._serialized_end=7257
  _LISTTICKETSINPUT_FILTER._serialized_start=6801
  _LISTTICKETSINPUT_FILTER._serialized_end=7185
  _LISTTICKETSINPUT_SORTABLE._serialized_start=7187
  _LISTTICKETSINPUT_SORTABLE._serialized_end=7257
  _LISTTICKETSOUTPUT._serialized_start=7259
  _LISTTICKETSOUTPUT._serialized_end=7330
  _REPLYTICKETINPUT._serialized_start=7332
  _REPLYTICKETINPUT._serialized_end=7401
  _REPLYTICKETOUTPUT._serialized_start=7403
  _REPLYTICKETOUTPUT._serialized_end=7440
  _LISTREPLIESINPUT._serialized_start=7442
  _LISTREPLIESINPUT._serialized_end=7509
  _LISTREPLIESOUTPUT._serialized_start=7511
  _LISTREPLIESOUTPUT._serialized_end=7581
  _DELETEREPLYINPUT._serialized_start=7583
  _DELETEREPLYINPUT._serialized_end=7619
  _DELETEREPLYOUTPUT._serialized_start=7621
  _DELETEREPLYOUTPUT._serialized_end=7640
  _UPDATEREPLYINPUT._serialized_start=7642
  _UPDATEREPLYINPUT._serialized_end=7695
  _UPDATEREPLYOUTPUT._serialized_start=7697
  _UPDATEREPLYOUTPUT._serialized_end=7716
  _CONFIGURERUNTIMEINPUT._serialized_start=7718
  _CONFIGURERUNTIMEINPUT._serialized_end=7778
  _CONFIGURERUNTIMEOUTPUT._serialized_start=7780
  _CONFIGURERUNTIMEOUTPUT._serialized_end=7804
  _DESCRIBERUNTIMEINPUT._serialized_start=7806
  _DESCRIBERUNTIMEINPUT._serialized_end=7848
  _DESCRIBERUNTIMEOUTPUT._serialized_start=7850
  _DESCRIBERUNTIMEOUTPUT._serialized_end=7890
  _CONFIGURESCORINGINPUT._serialized_start=7892
  _CONFIGURESCORINGINPUT._serialized_end=7983
  _CONFIGURESCORINGOUTPUT._serialized_start=7985
  _CONFIGURESCORINGOUTPUT._serialized_end=8009
  _DESCRIBESCORINGINPUT._serialized_start=8011
  _DESCRIBESCORINGINPUT._serialized_end=8053
  _DESCRIBESCORINGOUTPUT._serialized_start=8055
  _DESCRIBESCORINGOUTPUT._serialized_end=8126
  _CREATEANNOUNCEMENTINPUT._serialized_start=8128
  _CREATEANNOUNCEMENTINPUT._serialized_end=8223
  _CREATEANNOUNCEMENTOUTPUT._serialized_start=8225
  _CREATEANNOUNCEMENTOUTPUT._serialized_end=8263
  _UPDATEANNOUNCEMENTINPUT._serialized_start=8265
  _UPDATEANNOUNCEMENTINPUT._serialized_end=8365
  _UPDATEANNOUNCEMENTOUTPUT._serialized_start=8367
  _UPDATEANNOUNCEMENTOUTPUT._serialized_end=8393
  _DELETEANNOUNCEMENTINPUT._serialized_start=8395
  _DELETEANNOUNCEMENTINPUT._serialized_end=8445
  _DELETEANNOUNCEMENTOUTPUT._serialized_start=8447
  _DELETEANNOUNCEMENTOUTPUT._serialized_end=8473
  _READANNOUNCEMENTINPUT._serialized_start=8475
  _READANNOUNCEMENTINPUT._serialized_end=8523
  _READANNOUNCEMENTOUTPUT._serialized_start=8525
  _READANNOUNCEMENTOUTPUT._serialized_end=8549
  _DESCRIBEANNOUNCEMENTINPUT._serialized_start=8551
  _DESCRIBEANNOUNCEMENTINPUT._serialized_end=8603
  _DESCRIBEANNOUNCEMENTOUTPUT._serialized_start=8605
  _DESCRIBEANNOUNCEMENTOUTPUT._serialized_end=8683
  _DESCRIBEANNOUNCEMENTSTATUSINPUT._serialized_start=8685
  _DESCRIBEANNOUNCEMENTSTATUSINPUT._serialized_end=8743
  _DESCRIBEANNOUNCEMENTSTATUSOUTPUT._serialized_start=8745
  _DESCRIBEANNOUNCEMENTSTATUSOUTPUT._serialized_end=8796
  _LISTANNOUNCEMENTSINPUT._serialized_start=8799
  _LISTANNOUNCEMENTSINPUT._serialized_end=9040
  _LISTANNOUNCEMENTSINPUT_FILTER._serialized_start=8937
  _LISTANNOUNCEMENTSINPUT_FILTER._serialized_end=9040
  _LISTANNOUNCEMENTSOUTPUT._serialized_start=9042
  _LISTANNOUNCEMENTSOUTPUT._serialized_end=9125
  _DESCRIBECODETEMPLATEINPUT._serialized_start=9127
  _DESCRIBECODETEMPLATEINPUT._serialized_end=9194
  _DESCRIBECODETEMPLATEOUTPUT._serialized_start=9196
  _DESCRIBECODETEMPLATEOUTPUT._serialized_end=9242
  _CREATESCOREBOARDINPUT._serialized_start=9244
  _CREATESCOREBOARDINPUT._serialized_end=9333
  _CREATESCOREBOARDOUTPUT._serialized_start=9335
  _CREATESCOREBOARDOUTPUT._serialized_end=9382
  _UPDATESCOREBOARDINPUT._serialized_start=9384
  _UPDATESCOREBOARDINPUT._serialized_end=9476
  _UPDATESCOREBOARDOUTPUT._serialized_start=9478
  _UPDATESCOREBOARDOUTPUT._serialized_end=9502
  _REBUILDSCOREINPUT._serialized_start=9504
  _REBUILDSCOREINPUT._serialized_end=9543
  _REBUILDSCOREOUTPUT._serialized_start=9545
  _REBUILDSCOREOUTPUT._serialized_end=9586
  _DELETESCOREBOARDINPUT._serialized_start=9588
  _DELETESCOREBOARDINPUT._serialized_end=9634
  _DELETESCOREBOARDOUTPUT._serialized_start=9636
  _DELETESCOREBOARDOUTPUT._serialized_end=9660
  _DESCRIBESCOREBOARDINPUT._serialized_start=9662
  _DESCRIBESCOREBOARDINPUT._serialized_end=9710
  _DESCRIBESCOREBOARDOUTPUT._serialized_start=9712
  _DESCRIBESCOREBOARDOUTPUT._serialized_end=9784
  _DESCRIBEDEFAULTSCOREBOARDINPUT._serialized_start=9786
  _DESCRIBEDEFAULTSCOREBOARDINPUT._serialized_end=9838
  _DESCRIBEDEFAULTSCOREBOARDOUTPUT._serialized_start=9840
  _DESCRIBEDEFAULTSCOREBOARDOUTPUT._serialized_end=9919
  _LISTSCOREBOARDSINPUT._serialized_start=9922
  _LISTSCOREBOARDSINPUT._serialized_end=10211
  _LISTSCOREBOARDSINPUT_FILTER._serialized_start=10057
  _LISTSCOREBOARDSINPUT_FILTER._serialized_end=10211
  _LISTSCOREBOARDSOUTPUT._serialized_start=10213
  _LISTSCOREBOARDSOUTPUT._serialized_end=10292
  _DESCRIBESCOREBOARDHEADERINPUT._serialized_start=10294
  _DESCRIBESCOREBOARDHEADERINPUT._serialized_end=10348
  _DESCRIBESCOREBOARDHEADEROUTPUT._serialized_start=10351
  _DESCRIBESCOREBOARDHEADEROUTPUT._serialized_end=10506
  _DESCRIBESCOREBOARDHEADEROUTPUT_PROBLEM._serialized_start=10457
  _DESCRIBESCOREBOARDHEADEROUTPUT_PROBLEM._serialized_end=10506
  _DESCRIBESCOREBOARDFOOTERINPUT._serialized_start=10508
  _DESCRIBESCOREBOARDFOOTERINPUT._serialized_end=10562
  _DESCRIBESCOREBOARDFOOTEROUTPUT._serialized_start=10565
  _DESCRIBESCOREBOARDFOOTEROUTPUT._serialized_end=10750
  _DESCRIBESCOREBOARDFOOTEROUTPUT_PROBLEM._serialized_start=10671
  _DESCRIBESCOREBOARDFOOTEROUTPUT_PROBLEM._serialized_end=10750
  _DESCRIBESCOREBOARDROWINPUT._serialized_start=10752
  _DESCRIBESCOREBOARDROWINPUT._serialized_end=10827
  _DESCRIBESCOREBOARDROWOUTPUT._serialized_start=10829
  _DESCRIBESCOREBOARDROWOUTPUT._serialized_end=10901
  _INTROSPECTSCOREINPUT._serialized_start=10903
  _INTROSPECTSCOREINPUT._serialized_end=10945
  _INTROSPECTSCOREOUTPUT._serialized_start=10947
  _INTROSPECTSCOREOUTPUT._serialized_end=11006
  _DESCRIBESCOREINPUT._serialized_start=11008
  _DESCRIBESCOREINPUT._serialized_end=11121
  _DESCRIBESCOREOUTPUT._serialized_start=11123
  _DESCRIBESCOREOUTPUT._serialized_end=11180
  _IMPORTSCOREINPUT._serialized_start=11182
  _IMPORTSCOREINPUT._serialized_end=11261
  _IMPORTSCOREOUTPUT._serialized_start=11263
  _IMPORTSCOREOUTPUT._serialized_end=11282
  _LISTRESULTINPUT._serialized_start=11285
  _LISTRESULTINPUT._serialized_end=11421
  _LISTRESULTOUTPUT._serialized_start=11423
  _LISTRESULTOUTPUT._serialized_end=11493
  _DESCRIBEDEFAULTSCOREBOARDROWINPUT._serialized_start=11495
  _DESCRIBEDEFAULTSCOREBOARDROWINPUT._serialized_end=11574
  _DESCRIBEDEFAULTSCOREBOARDROWOUTPUT._serialized_start=11576
  _DESCRIBEDEFAULTSCOREBOARDROWOUTPUT._serialized_end=11655
  _LISTSCOREBOARDROWSINPUT._serialized_start=11658
  _LISTSCOREBOARDROWSINPUT._serialized_end=12238
  _LISTSCOREBOARDROWSINPUT_FILTER._serialized_start=11802
  _LISTSCOREBOARDROWSINPUT_FILTER._serialized_end=12238
  _LISTSCOREBOARDROWSOUTPUT._serialized_start=12240
  _LISTSCOREBOARDROWSOUTPUT._serialized_end=12326
  _LISTDEFAULTSCOREBOARDROWSINPUT._serialized_start=12329
  _LISTDEFAULTSCOREBOARDROWSINPUT._serialized_end=12474
  _LISTDEFAULTSCOREBOARDROWSOUTPUT._serialized_start=12476
  _LISTDEFAULTSCOREBOARDROWSOUTPUT._serialized_end=12569
  _LISTENTITLEMENTSINPUT._serialized_start=12572
  _LISTENTITLEMENTSINPUT._serialized_end=12700
  _LISTENTITLEMENTSOUTPUT._serialized_start=12702
  _LISTENTITLEMENTSOUTPUT._serialized_end=12775
  _LISTACTIVITIESINPUT._serialized_start=12777
  _LISTACTIVITIESINPUT._serialized_end=12848
  _LISTACTIVITIESOUTPUT._serialized_start=12850
  _LISTACTIVITIESOUTPUT._serialized_end=12926
  _CONFIGUREAPPEARANCEINPUT._serialized_start=12928
  _CONFIGUREAPPEARANCEINPUT._serialized_end=13028
  _CONFIGUREAPPEARANCEOUTPUT._serialized_start=13030
  _CONFIGUREAPPEARANCEOUTPUT._serialized_end=13057
  _DESCRIBEAPPEARANCEINPUT._serialized_start=13059
  _DESCRIBEAPPEARANCEINPUT._serialized_end=13104
  _DESCRIBEAPPEARANCEOUTPUT._serialized_start=13106
  _DESCRIBEAPPEARANCEOUTPUT._serialized_end=13186
  _JUDGE._serialized_start=13189
  _JUDGE._serialized_end=27915
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.geography import country_pb2 as _country_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DescribeCountryInput(_message.Message):
    __slots__ = ["country_id"]
    COUNTRY_ID_FIELD_NUMBER: _ClassVar[int]
    country_id: str
    def __init__(self, country_id: _Optional[str] = ...) -> None: ...

class DescribeCountryOutput(_message.Message):
    __slots__ = ["country"]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    country: _country_pb2.Country
    def __init__(self, country: _Optional[_Union[_country_pb2.Country, _Mapping]] = ...) -> None: ...

class ListCountriesInput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ListCountriesOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_country_pb2.Country]
    total: int
    def __init__(self, items: _Optional[_Iterable[_Union[_country_pb2.Country, _Mapping]]] = ..., total: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/test.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x65olymp/atlas/test.proto\x12\x0c\x65olymp.atlas\"\x88\x01\n\x04Test\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\x05\x12\x0f\n\x07\x65xample\x18\x04 \x01(\x08\x12\r\n\x05score\x18\x05 \x01(\x02\x12\x17\n\x0finput_object_id\x18\n \x01(\t\x12\x18\n\x10\x61nswer_object_id\x18\x14 \x01(\tB3Z1github.com/eolymp/contracts/go/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.test_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/contracts/go/eolymp/atlas;atlas'
  _TEST._serialized_start=42
  _TEST._serialized_end=178
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/workspace/project.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65olymp/workspace/project.proto\x12\x10\x65olymp.workspace\"\xde\x01\n\x07Project\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07runtime\x18\x03 \x01(\t\x12\x38\n\nvisibility\x18\x04 \x01(\x0e\x32$.eolymp.workspace.Project.Visibility\x12\x11\n\tauthor_id\x18\x05 \x01(\t\x12\x1a\n\x10\x61tlas_problem_id\x18\n \x01(\tH\x00\x12\x0e\n\x06labels\x18\x64 \x03(\t\"%\n\nVisibility\x12\x0b\n\x07PRIVATE\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x42\x08\n\x06targetB;Z9github.com/eolymp/contracts/go/eolymp/workspace;workspaceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.workspace.project_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z9github.com/eolymp/contracts/go/eolymp/workspace;workspace'
  _PROJECT._serialized_start=53
  _PROJECT._serialized_end=275
  _PROJECT_VISIBILITY._serialized_start=228
  _PROJECT_VISIBILITY._serialized_end=265
# @@protoc_insertion_point(module_scope)



from eolymp.judge import feedback_pb2 as _feedback_pb2
from eolymp.typewriter import block_pb2 as _block_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Problem(_message.Message):
    __slots__ = ["base_id", "contest_id", "feedback_policy", "file_size_limit", "id", "index", "memory_limit", "score", "score_by_best_testset", "submit_limit", "time_limit"]
    class Attachment(_message.Message):
        __slots__ = ["id", "link", "name"]
        ID_FIELD_NUMBER: _ClassVar[int]
        LINK_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        id: str
        link: str
        name: str
        def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., link: _Optional[str] = ...) -> None: ...
    class Statement(_message.Message):
        __slots__ = ["content", "content_rich", "download_link", "format", "locale", "title"]
        class Format(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = []
        CONTENT_FIELD_NUMBER: _ClassVar[int]
        CONTENT_RICH_FIELD_NUMBER: _ClassVar[int]
        DOWNLOAD_LINK_FIELD_NUMBER: _ClassVar[int]
        FORMAT_FIELD_NUMBER: _ClassVar[int]
        HTML: Problem.Statement.Format
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        MARKDOWN: Problem.Statement.Format
        NONE: Problem.Statement.Format
        RICH: Problem.Statement.Format
        TEX: Problem.Statement.Format
        TITLE_FIELD_NUMBER: _ClassVar[int]
        content: str
        content_rich: _block_pb2.Container
        download_link: str
        format: Problem.Statement.Format
        locale: str
        title: str
        def __init__(self, locale: _Optional[str] = ..., title: _Optional[str] = ..., content: _Optional[str] = ..., content_rich: _Optional[_Union[_block_pb2.Container, _Mapping]] = ..., format: _Optional[_Union[Problem.Statement.Format, str]] = ..., download_link: _Optional[str] = ...) -> None: ...
    class Test(_message.Message):
        __slots__ = ["answer_object_id", "example", "index", "input_object_id", "score"]
        ANSWER_OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
        EXAMPLE_FIELD_NUMBER: _ClassVar[int]
        INDEX_FIELD_NUMBER: _ClassVar[int]
        INPUT_OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
        SCORE_FIELD_NUMBER: _ClassVar[int]
        answer_object_id: str
        example: bool
        index: int
        input_object_id: str
        score: float
        def __init__(self, index: _Optional[int] = ..., example: bool = ..., input_object_id: _Optional[str] = ..., answer_object_id: _Optional[str] = ..., score: _Optional[float] = ...) -> None: ...
    BASE_ID_FIELD_NUMBER: _ClassVar[int]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    FEEDBACK_POLICY_FIELD_NUMBER: _ClassVar[int]
    FILE_SIZE_LIMIT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    MEMORY_LIMIT_FIELD_NUMBER: _ClassVar[int]
    SCORE_BY_BEST_TESTSET_FIELD_NUMBER: _ClassVar[int]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    SUBMIT_LIMIT_FIELD_NUMBER: _ClassVar[int]
    TIME_LIMIT_FIELD_NUMBER: _ClassVar[int]
    base_id: str
    contest_id: str
    feedback_policy: _feedback_pb2.FeedbackPolicy
    file_size_limit: int
    id: str
    index: int
    memory_limit: int
    score: float
    score_by_best_testset: bool
    submit_limit: int
    time_limit: int
    def __init__(self, id: _Optional[str] = ..., index: _Optional[int] = ..., score: _Optional[float] = ..., base_id: _Optional[str] = ..., contest_id: _Optional[str] = ..., feedback_policy: _Optional[_Union[_feedback_pb2.FeedbackPolicy, str]] = ..., time_limit: _Optional[int] = ..., memory_limit: _Optional[int] = ..., file_size_limit: _Optional[int] = ..., submit_limit: _Optional[int] = ..., score_by_best_testset: bool = ...) -> None: ...



from eolymp.ranker import format_pb2 as _format_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Scoreboard(_message.Message):
    __slots__ = ["format", "id", "key", "name"]
    class Column(_message.Message):
        __slots__ = ["columns", "community_attribute_key", "id", "index", "judge_contest_id", "judge_problem_id", "key", "name", "parent_id", "short_name", "type", "visible"]
        class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = []
        ATTRIBUTE: Scoreboard.Column.Type
        COLUMNS_FIELD_NUMBER: _ClassVar[int]
        COMMUNITY_ATTRIBUTE_KEY_FIELD_NUMBER: _ClassVar[int]
        CONTEST: Scoreboard.Column.Type
        ID_FIELD_NUMBER: _ClassVar[int]
        INDEX_FIELD_NUMBER: _ClassVar[int]
        JUDGE_CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
        JUDGE_PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
        KEY_FIELD_NUMBER: _ClassVar[int]
        NAME: Scoreboard.Column.Type
        NAME_FIELD_NUMBER: _ClassVar[int]
        NONE: Scoreboard.Column.Type
        PARENT_ID_FIELD_NUMBER: _ClassVar[int]
        PROBLEM: Scoreboard.Column.Type
        SHORT_NAME_FIELD_NUMBER: _ClassVar[int]
        TYPE_FIELD_NUMBER: _ClassVar[int]
        VISIBLE_FIELD_NUMBER: _ClassVar[int]
        columns: _containers.RepeatedCompositeFieldContainer[Scoreboard.Column]
        community_attribute_key: str
        id: str
        index: int
        judge_contest_id: str
        judge_problem_id: str
        key: str
        name: str
        parent_id: str
        short_name: str
        type: Scoreboard.Column.Type
        visible: bool
        def __init__(self, id: _Optional[str] = ..., parent_id: _Optional[str] = ..., key: _Optional[str] = ..., name: _Optional[str] = ..., short_name: _Optional[str] = ..., type: _Optional[_Union[Scoreboard.Column.Type, str]] = ..., index: _Optional[int] = ..., visible: bool = ..., judge_contest_id: _Optional[str] = ..., judge_problem_id: _Optional[str] = ..., community_attribute_key: _Optional[str] = ..., columns: _Optional[_Iterable[_Union[Scoreboard.Column, _Mapping]]] = ...) -> None: ...
    class Row(_message.Message):
        __slots__ = ["id", "member_id", "name", "penalty", "rank", "rank_lower", "score", "values"]
        class Value(_message.Message):
            __slots__ = ["attempts", "column_id", "id", "penalty", "percentage", "score", "solved_in", "value_number", "value_string"]
            ATTEMPTS_FIELD_NUMBER: _ClassVar[int]
            COLUMN_ID_FIELD_NUMBER: _ClassVar[int]
            ID_FIELD_NUMBER: _ClassVar[int]
            PENALTY_FIELD_NUMBER: _ClassVar[int]
            PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
            SCORE_FIELD_NUMBER: _ClassVar[int]
            SOLVED_IN_FIELD_NUMBER: _ClassVar[int]
            VALUE_NUMBER_FIELD_NUMBER: _ClassVar[int]
            VALUE_STRING_FIELD_NUMBER: _ClassVar[int]
            attempts: int
            column_id: str
            id: str
            penalty: float
            percentage: float
            score: float
            solved_in: int
            value_number: int
            value_string: str
            def __init__(self, id: _Optional[str] = ..., column_id: _Optional[str] = ..., score: _Optional[float] = ..., penalty: _Optional[float] = ..., percentage: _Optional[float] = ..., attempts: _Optional[int] = ..., solved_in: _Optional[int] = ..., value_string: _Optional[str] = ..., value_number: _Optional[int] = ...) -> None: ...
        ID_FIELD_NUMBER: _ClassVar[int]
        MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        PENALTY_FIELD_NUMBER: _ClassVar[int]
        RANK_FIELD_NUMBER: _ClassVar[int]
        RANK_LOWER_FIELD_NUMBER: _ClassVar[int]
        SCORE_FIELD_NUMBER: _ClassVar[int]
        VALUES_FIELD_NUMBER: _ClassVar[int]
        id: str
        member_id: str
        name: str
        penalty: float
        rank: int
        rank_lower: int
        score: float
        values: _containers.RepeatedCompositeFieldContainer[Scoreboard.Row.Value]
        def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., member_id: _Optional[str] = ..., score: _Optional[float] = ..., penalty: _Optional[float] = ..., rank: _Optional[int] = ..., rank_lower: _Optional[int] = ..., values: _Optional[_Iterable[_Union[Scoreboard.Row.Value, _Mapping]]] = ...) -> None: ...
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    format: _format_pb2.Format
    id: str
    key: str
    name: str
    def __init__(self, id: _Optional[str] = ..., key: _Optional[str] = ..., name: _Optional[str] = ..., format: _Optional[_Union[_format_pb2.Format, str]] = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Interactor(_message.Message):
    __slots__ = ["lang", "source", "type"]
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    LANG_FIELD_NUMBER: _ClassVar[int]
    NONE: Interactor.Type
    PROGRAM: Interactor.Type
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    lang: str
    source: str
    type: Interactor.Type
    def __init__(self, type: _Optional[_Union[Interactor.Type, str]] = ..., lang: _Optional[str] = ..., source: _Optional[str] = ...) -> None: ...
